#
# spec file for package python-django-mailer
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python36 1
Name:           python-django-mailer
Version:        2.3.2
Release:        2.1
Summary:        A reusable Django app for queuing the sending of email
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/pinax/django-mailer/
Source:         https://files.pythonhosted.org/packages/source/d/django-mailer/django-mailer-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
Requires:       python-lockfile >= 0.8
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module lockfile >= 0.8}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
A reusable Django app for queuing and throttling of email sending, scheduled sending,
consolidation of multiple notifications into single emails and logging of mail failures.

%prep
%autosetup -p1 -n django-mailer-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_send_html fails with Django 5.2 https://github.com/pinax/django-mailer/issues/182
%pytest -k "not test_send_html"

%files %{python_files}
%doc AUTHORS CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/*mailer*/

%changelog
* Tue Apr 22 2025 Markéta Machová <mmachova@suse.com>
- Skip failing test with Django 5.2
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.2:
  * Added MAILER_EMAIL_LOG_MESSAGE_DATA setting
  * Added support for psycopg3 for runmailer_pc
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Fixed rare crasher in runmailer_pg when notifications list is
    empty.
* Mon Oct  2 2023 pgajdos@suse.com
- version update to 2.3
  2.3 - 2023-09-25
  - ---------------
  * Dropped Python 3.7 support.
  * Added ``runmailer_pg`` - advanced sending method for sending emails without delay
    immediate, PostgreSQL only.
  2.2.1 - 2023-09-22
  - -----------------
  * Added admin action to send messages
  * Added fix for email address that is a ``NoneType``
  * Stopped testing on unsupported Python (<3.7) and Django (<2.2) versions
  * Started testing on Python 3.11 and Django 4.1/4.2
  * Added setting to limit the amount of retries for deferred messages
    (``MAILER_EMAIL_MAX_RETRIES``), defaults to ``None`` (unlimited)
    (See Issue `#161 <https://github.com/pinax/django-mailer/issues/161>`_
- deleted patches
  - python-django-mailer-no-mock.patch (upstreamed)
* Mon May  9 2022 pgajdos@suse.com
- version update to 2.2
  * Migrate models ``id`` fields to ``BigAutoField``.
  * Add ``runmailer`` management command. This command starts a loop that
  * Added ``runmailer`` management command. This command starts a loop that
    frequently checks the database for new emails. The wait time between
    checks can be controlled using the ``MAILER_EMPTY_QUEUE_SLEEP`` setting.
- added patches
  fix https://github.com/pinax/django-mailer/issues/157
  + python-django-mailer-no-mock.patch
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sun Dec 26 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.1
  * The retry_deferred and send_mail commands rely on the log level
    set in your django project now. The -c/--cron option in those
    commands has been deprecated and the logic to configure log
    levels and the message format has been removed.
  * Changed logging to use module specific loggers to avoid
    interfering with other loggers.
  * Added MAILER_USE_FILE_LOCK setting to allow disabling file based
    locking.
  * Added -r option to purge_mail_log management command.
  * Fixed deprecation warnings on Django 3.1
  * Use cached DNS_NAME for performance
  * Added ability to override the default error handler via the
    MAILER_ERROR_HANDLER settings key
* Tue Jun 30 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Sun May 24 2020 John Vandenberg <jayvdb@gmail.com>
- Use single spec
- Update to v2.0.1
* Wed Dec 28 2011 alexandre@exatati.com.br
- Remove CFLAGS from spec file.
* Thu Nov 24 2011 alexandre@exatati.com.br
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Mon Aug 24 2009 alexandre@exatati.com.br
- Update to 0.1 final.
* Wed Aug 19 2009 alexandre@exatati.com.br
- Initial package for openSUSE.
